@@ -66,7 +66,9 @@ class Service(ConsumerMixin):
             message.ack()
 
     def handle_request(self, body):
-        with self._connection_pool.get() as connection:
+        # item is patched on for python with ``with``, pylint can't find it
+        # pylint: disable=E1102
+        with self._connection_pool.item() as connection:
             nameko.process_message(connection, self.controller, body)
 
     def wait(self):
